# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d

class XSingleSelectQueryAnalyzer(XInterface_8f010a43):
    """
    simplifies the analyzing of single select statements.
    
    The interface can be used for analyzing single SELECT statements without knowing the structure of the used query.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API XSingleSelectQueryAnalyzer <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XSingleSelectQueryAnalyzer.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.XSingleSelectQueryAnalyzer'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sdb.XSingleSelectQueryAnalyzer'

    @abstractmethod
    def getFilter(self) -> str:
        """
        returns the used filter.
        
        The filter criteria returned is part of the where condition of the select command, but it does not contain the where token.
        """
        ...
    @abstractmethod
    def getGroup(self) -> str:
        """
        returns the currently used GROUP BY.
        
        The group criteria returned is part of the GROUP BY clause of the select command, but it does not contain the GROUP BY keyword .
        """
        ...
    @abstractmethod
    def getGroupColumns(self) -> XIndexAccess_f0910d6d:
        """
        returns the currently used group.
        
        The columns returned from the GROUP BY clause.
        """
        ...
    @abstractmethod
    def getHavingClause(self) -> str:
        """
        returns the used HAVING filter.
        
        The HAVING filter criteria returned is part of the HAVING condition of the select command, but it does not contain the HAVING token.
        """
        ...
    @abstractmethod
    def getOrder(self) -> str:
        """
        returns the currently used sort order.
        
        The order criteria returned is part of the ORDER BY clause of the select command, but it does not contain the ORDER BY keyword .
        """
        ...
    @abstractmethod
    def getOrderColumns(self) -> XIndexAccess_f0910d6d:
        """
        returns the currently used sort order.
        
        The order criteria returned is part of the ORDER BY clause of the select command, but it does not contain the ORDER BY keyword .
        """
        ...
    @abstractmethod
    def getQuery(self) -> str:
        """
        returns the query.
        """
        ...
    @abstractmethod
    def getQueryWithSubstitution(self) -> str:
        """
        returns the query previously set at the analyzer, with all application-level features being substituted by their database-level counterparts.
        
        The XSingleSelectQueryAnalyzer is an application-level component, which in some respect understands SQL features usually not present at the database level. As a prominent example, you might pass a SELECT statement to the analyzer which is based on another query.
        
        While all other methods will handle those additional features transparently - e.g. the query in the FROM part of a SELECT statement will be handled as if it really is a table -, getQueryWithSubstitution gives you the SQL statement where all those features have been stripped, and replaced with appropriate standard SQL.
        
        For example, consider a database document which contains a client-side query named All Orders. This query is not known to the underlying database, so an SQL statement like SELECT * from \"All Orders\" would be rejected by the database. However, instantiating a SingleSelectQueryAnalyzer at the Connection object, and passing it the above query, you can then use getQueryWithSubstitution to retrieve a statement where \"All Orders\" has been replaced with the SELECT statement which actually constitutes the \"All Orders\" query.
        
        **since**
        
            OOo 2.0.4

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def getStructuredFilter(self) -> typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]:
        """
        returns the currently used filter.
        
        The filter criteria is split into levels. Each level represents the OR criteria. Within each level, the filters are provided as an AND criteria with the name of the column and the filter condition. The filter condition is of type string. The operator used, is defined by com.sun.star.sdb.SQLFilterOperator.
        """
        ...
    @abstractmethod
    def getStructuredHavingClause(self) -> typing.Tuple[typing.Tuple[PropertyValue_c9610c73, ...], ...]:
        """
        returns the currently used HAVING filter.
        
        The HAVING filter criteria is split into levels. Each level represents the OR criteria. Within each level, the filters are provided as an AND criteria with the name of the column and the filter condition. The filter condition is of type string. The operator used, is defined by com.sun.star.sdb.SQLFilterOperator.
        """
        ...
    @abstractmethod
    def setCommand(self, Command: str, CommandType: int) -> None:
        """
        sets a new query for the composer, which may be expanded by filters, group by, having and sort criteria.
        
        In case of a CommandType of com.sun.star.sdb.CommandType.COMMAND, means in case the Command specifies an SQL statement, the inherited com.sun.star.sdbc.RowSet.EscapeProcessing becomes relevant:It then can be to used to specify whether the SQL statement should be analyzed on the client side before sending it to the database server.The default value for com.sun.star.sdbc.RowSet.EscapeProcessing is TRUE. By switching it to FALSE, you can pass backend-specific SQL statements, which are not standard SQL, to your database.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...
    @abstractmethod
    def setQuery(self, command: str) -> None:
        """
        sets a new query for the composer, which may be expanded by filters, group by, having and sort criteria.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
        ...

__all__ = ['XSingleSelectQueryAnalyzer']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.java
from __future__ import annotations
import uno
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XJavaVM(XInterface_8f010a43):
    """
    must be implemented by the user of the XJavaVM.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API XJavaVM <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1java_1_1XJavaVM.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.java'
    __ooo_full_ns__: str = 'com.sun.star.java.XJavaVM'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.java.XJavaVM'

    @abstractmethod
    def getJavaVM(self, processID: uno.ByteSequence) -> object:
        """
        returns the address of the Java Virtual Machine.
        
        If the VM is not already instantiated, it will be now.
        
        If the processID is a normal 16-byte ID, the returned any contains a JNI JavaVM pointer as a long or hyper integer (depending on the platform). If the processID does not match the current process, or if the VM cannot be instantiated for whatever reason, a VOID any is returned.
        
        If the processID has an additional 17th byte of value 0, the returned any contains a non–reference-counted pointer to a (reference-counted) instance of the C++ jvmaccess.VirtualMachine class, always represented as a hyper integer. The pointer is guaranteed to be valid as long as the reference to this com.sun.star.java.XJavaVM is valid (but the pointer should be converted into a reference-counted reference as soon as possible). Again, if the first 16 bytes of the processID do not match the current process, or if the VM cannot be instantiated for whatever reason, a VOID any is returned.
        
        If the processID has an additional 17th byte of value 1, the returned any contains a non–reference-counted pointer to a (reference-counted) instance of the C++ jvmaccess.UnoVirtualMachine class, always represented as a hyper integer. The pointer is guaranteed to be valid as long as the reference to this com.sun.star.java.XJavaVM is valid. Again, if the first 16 bytes of the processID do not match the current process, or if the VM cannot be instantiated for whatever reason, a VOID any is returned.
        
        The first form (returning a JNI JavaVM pointer) is mainly for backwards compatibility, new code should use the second form (returning a pointer to a jvmaccess.VirtualMachine) if it does not want to use the Java UNO environment, and it should use the third form (returning a pointer to a jvmaccess.UnoVirtualMachine) if it wants to use the Java UNO environment. For example, one advantage of using jvmaccess.VirtualMachine instead of the raw JavaVM pointer is that whenever you attach a native thread to the Java virtual machine, that thread's context ClassLoader (see java.lang.Thread.getContextClassLoader) will automatically be set to a meaningful value.
        """
        ...
    @abstractmethod
    def isVMEnabled(self) -> bool:
        """
        Returns TRUE if the VM is enabled.
        
        It is only possible to get the VM, if this method return 0.
        """
        ...
    @abstractmethod
    def isVMStarted(self) -> bool:
        """
        returns TRUE if the VM is started successfully, otherwise FALSE.
        """
        ...

__all__ = ['XJavaVM']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from abc import abstractproperty
from .chart_axis_x_supplier import ChartAxisXSupplier as ChartAxisXSupplier_a950e4d
from .chart_axis_z_supplier import ChartAxisZSupplier as ChartAxisZSupplier_aa70e4f
from .chart_statistics import ChartStatistics as ChartStatistics_e2190d37
from .chart_two_axis_y_supplier import ChartTwoAxisYSupplier as ChartTwoAxisYSupplier_380d0f88
from .diagram import Diagram as Diagram_844409cf
from .dim3_d_diagram import Dim3DDiagram as Dim3DDiagram_b7a60b60
from .stackable_diagram import StackableDiagram as StackableDiagram_ee760d59

class BarDiagram(ChartAxisXSupplier_a950e4d, ChartAxisZSupplier_aa70e4f, ChartStatistics_e2190d37, ChartTwoAxisYSupplier_380d0f88, Diagram_844409cf, Dim3DDiagram_b7a60b60, StackableDiagram_ee760d59):
    """
    Service Class

    This is a service for bar and column diagrams.

    See Also:
        `API BarDiagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1BarDiagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.BarDiagram'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Deep(self) -> bool:
        """
        If TRUE, determines that in a three-dimensional bar chart the bars of each series are arranged behind each other in the z-direction.
        
        If FALSE the arrangement of bars is like in two-dimensional bar charts.
        """
        ...

    @abstractproperty
    def GroupBarsPerAxis(self) -> bool:
        """
        If bars of a bar or column chart are attached to different axis, this property determines how to display those.
        
        If TRUE, the bars are grouped together in one block for each axis, thus they are painted one group over the other.
        
        If FALSE, the bars are displayed side-by-side, as if they were all attached to the same axis.
        
        If all data series of a bar or column chart are attached to only one axis, this property has no effect.
        """
        ...

    @abstractproperty
    def NumberOfLines(self) -> int:
        """
        Determines how many data rows are displayed as lines rather than bars.
        
        If this property differs from zero the last BarDiagram.NumberOfLines data rows are shown as lines. It is currently supported by two dimensional vertical bar charts only.
        """
        ...

    @abstractproperty
    def StackedBarsConnected(self) -> bool:
        """
        determines if, in a stacked chart, there are connecting lines between corresponding bars.
        
        Currently, bar charts with horizontal bars do not support this property.
        """
        ...

    @abstractproperty
    def Vertical(self) -> bool:
        """
        Determines if the bars of a chart are drawn vertically or horizontally.
        
        Default is vertical.
        
        If Vertical is FALSE you get a column chart rather than a bar chart.
        """
        ...


__all__ = ['BarDiagram']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet_7bd4114e
from ..document.x_action_lockable import XActionLockable as XActionLockable_cb30e3a
from .sheet_ranges_query import SheetRangesQuery as SheetRangesQuery_efbe0d90
from .x_cell_addressable import XCellAddressable as XCellAddressable_ed700d53
from .x_sheet_annotation_anchor import XSheetAnnotationAnchor as XSheetAnnotationAnchor_48670fe8
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..style.character_properties_asian import CharacterPropertiesAsian as CharacterPropertiesAsian_6d8a10df
from ..style.character_properties_complex import CharacterPropertiesComplex as CharacterPropertiesComplex_90ca11cb
from ..style.paragraph_properties import ParagraphProperties as ParagraphProperties_1e240efc
from ..style.paragraph_properties_asian import ParagraphPropertiesAsian as ParagraphPropertiesAsian_6e8c10e8
from ..style.paragraph_properties_complex import ParagraphPropertiesComplex as ParagraphPropertiesComplex_91de11d4
from ..table.cell import Cell as Cell_680c0890
from ..table.x_column_row_range import XColumnRowRange as XColumnRowRange_e0e70cfb
from ..text.text import Text as Text_607f0872
from ..text.x_text_fields_supplier import XTextFieldsSupplier as XTextFieldsSupplier_d5d0e75
from ..util.x_indent import XIndent as XIndent_7b290980
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
from ..util.x_replaceable import XReplaceable as XReplaceable_b0750b6e
if typing.TYPE_CHECKING:
    from ..awt.point import Point as Point_5fb2085e
    from ..awt.size import Size as Size_576707ef
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
    from .x_sheet_conditional_entries import XSheetConditionalEntries as XSheetConditionalEntries_694810c0
    from com.sun.star.table.CellContentType import CellContentTypeProto  # type: ignore

class SheetCell(SheetRangesQuery_efbe0d90, CharacterProperties_1d4f0ef3, CharacterPropertiesAsian_6d8a10df, CharacterPropertiesComplex_90ca11cb, ParagraphProperties_1e240efc, ParagraphPropertiesAsian_6e8c10e8, ParagraphPropertiesComplex_91de11d4, Cell_680c0890, Text_607f0872, XTolerantMultiPropertySet_7bd4114e, XActionLockable_cb30e3a, XCellAddressable_ed700d53, XSheetAnnotationAnchor_48670fe8, XColumnRowRange_e0e70cfb, XTextFieldsSupplier_d5d0e75, XIndent_7b290980, XModifyBroadcaster_fd990df0, XReplaceable_b0750b6e):
    """
    Service Class

    represents a single addressable cell in a spreadsheet document.
    
    **since**
    
        OOo 2.0

    See Also:
        `API SheetCell <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SheetCell.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SheetCell'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def AbsoluteName(self) -> str:
        """
        Returns the absolute address of the range as string, e.g.
        
        \"$Sheet1.$B$2\".
        """
        ...

    @abstractproperty
    def CellContentType(self) -> CellContentTypeProto:
        """
        contains the content type of the cell.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def ConditionalFormat(self) -> XSheetConditionalEntries_694810c0:
        """
        contains the conditional formatting settings for this cell.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def ConditionalFormatLocal(self) -> XSheetConditionalEntries_694810c0:
        """
        contains the conditional formatting settings for this cell, using localized formulas.
        
        After a conditional format has been changed it has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def FormulaLocal(self) -> str:
        """
        contains the formula string with localized function names.
        
        This property can also be used to set a new localized formula.
        """
        ...

    @abstractproperty
    def FormulaResultType(self) -> int:
        """
        contains the content type of the cell.
        
        This property returns not com.sun.star.sheet.FormulaResult but instead com.sun.star.table.CellContentType. Use FormulaResult2 if the correct property is needed.
        """
        ...

    @abstractproperty
    def FormulaResultType2(self) -> int:
        """
        contains the result type of a formula.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def Position(self) -> Point_5fb2085e:
        """
        contains the position of this cell in the sheet (in 1/100 mm).
        
        This property contains the absolute position in the whole sheet, not the position in the visible area.
        """
        ...

    @abstractproperty
    def Size(self) -> Size_576707ef:
        """
        contains the size of this cell (in 1/100 mm).
        """
        ...

    @abstractproperty
    def Validation(self) -> XPropertySet_bc180bfa:
        """
        contains the data validation settings for this cell.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """
        ...

    @abstractproperty
    def ValidationLocal(self) -> XPropertySet_bc180bfa:
        """
        contains the data validation settings for this cell, using localized formulas.
        
        After the data validation settings have been changed the validation has to be reinserted into the property set.
        """
        ...


__all__ = ['SheetCell']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..table.cell_address import CellAddress as CellAddress_ae5f0b56
    from com.sun.star.sheet.ConditionOperator import ConditionOperatorProto  # type: ignore
    from com.sun.star.sheet.ConditionOperator import ConditionOperatorProto  # type: ignore

class XSheetCondition(XInterface_8f010a43):
    """
    provides methods to access the settings of a condition in a conditional format or data validation.

    See Also:
        `API XSheetCondition <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sheet_1_1XSheetCondition.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.XSheetCondition'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.sheet.XSheetCondition'

    @abstractmethod
    def getFormula1(self) -> str:
        """
        returns either the comparison value, which is used in the condition, or the first value if two values are needed for the operator.
        """
        ...
    @abstractmethod
    def getFormula2(self) -> str:
        """
        if two values are needed for the operator, this method returns the second one.
        """
        ...
    @abstractmethod
    def getOperator(self) -> ConditionOperatorProto:
        """
        returns the operator in the condition.
        """
        ...
    @abstractmethod
    def getSourcePosition(self) -> CellAddress_ae5f0b56:
        """
        returns the position in the document which is used as a base for relative references in the formulas.
        """
        ...
    @abstractmethod
    def setFormula1(self, aFormula1: str) -> None:
        """
        sets either the comparison value, which is used in the condition, or the first value if two values are needed for the operator.
        """
        ...
    @abstractmethod
    def setFormula2(self, aFormula2: str) -> None:
        """
        if two values are needed for the operator, this method sets the second one.
        """
        ...
    @abstractmethod
    def setOperator(self, nOperator: ConditionOperatorProto) -> None:
        """
        sets the operator in the condition.
        """
        ...
    @abstractmethod
    def setSourcePosition(self, aSourcePosition: CellAddress_ae5f0b56) -> None:
        """
        sets the position in the document which is used as a base for relative references in the formulas.
        """
        ...

__all__ = ['XSheetCondition']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..awt.font_descriptor import FontDescriptor as FontDescriptor_bc110c0a
    from ..util.color import Color as Color_68e908c5

class DataSettings(ABC):
    """
    Service Class

    extends the com.sun.star.sdbcx.Table with additional display information, sorting and filtering criteria.

    See Also:
        `API DataSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DataSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.DataSettings'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def ApplyFilter(self) -> bool:
        """
        indicates whether the filter should be applied or not, default is FALSE.
        """
        ...

    @abstractproperty
    def Filter(self) -> str:
        """
        additional filter for the data object.
        """
        ...

    @abstractproperty
    def FontDescriptor(self) -> FontDescriptor_bc110c0a:
        """
        specifies the font attributes for data displaying.
        """
        ...

    @abstractproperty
    def GroupBy(self) -> str:
        """
        additional group by for the data object.
        """
        ...

    @abstractproperty
    def HavingClause(self) -> str:
        """
        additional having clause for the data object.
        """
        ...

    @abstractproperty
    def Order(self) -> str:
        """
        is an additional sort order definition.
        """
        ...

    @abstractproperty
    def RowHeight(self) -> int:
        """
        specifies the height of a data row.
        """
        ...

    @abstractproperty
    def TextColor(self) -> Color_68e908c5:
        """
        specifies the text color (RGB) for displaying text.
        """
        ...


__all__ = ['DataSettings']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class X3DDefaultSetter(XInterface_8f010a43):
    """
    makes it easy to set suitable defaults for illumination and rotation for 3D charts

    See Also:
        `API X3DDefaultSetter <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1chart_1_1X3DDefaultSetter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.X3DDefaultSetter'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.chart.X3DDefaultSetter'

    @abstractmethod
    def set3DSettingsToDefault(self) -> None:
        """
        The result may depend on the current chart type and the current shade mode.
        """
        ...
    @abstractmethod
    def setDefaultIllumination(self) -> None:
        """
        set suitable defaults for the illumination of the current 3D chart.
        
        The result may dependent on other 3D settings as rotation or shade mode. It may depend on the current chart type also.
        """
        ...
    @abstractmethod
    def setDefaultRotation(self) -> None:
        """
        sets a suitable default for the rotation of the current 3D chart.
        
        The result may depend on the current chart type.
        """
        ...

__all__ = ['X3DDefaultSetter']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from abc import abstractmethod
from .x_close_broadcaster import XCloseBroadcaster as XCloseBroadcaster_ef230d7e

class XCloseable(XCloseBroadcaster_ef230d7e):
    """
    makes it possible to release any objects in an ordered manner by using a two-step mechanism
    
    If an object should be terminated, it can be:
    
    First version gives the object no chance to disagree with that (e.g. if a process is still running and can't be canceled really). Last version provides this possibility, but can't guarantee real termination of called object. It depends from the environment of an object, if one or both mechanism are necessary.
    
    Base interface XCloseBroadcaster makes it possible that any listener which is interested on life time of listened object ...

    See Also:
        `API XCloseable <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XCloseable.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XCloseable'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XCloseable'

    @abstractmethod
    def close(self, DeliverOwnership: bool) -> None:
        """
        try to close the object
        
        Must definitely be called before com.sun.star.lang.XComponent.dispose(). But nobody can guarantee real closing of called object - because it can disagree with that if any still running processes can't be canceled yet. It's not allowed to block this call till internal operations will be finished here. They must be canceled or call must return immediately by throwing the CloseVetoException. Otherwise (if nothing exist to disagree) it must return normally.
        
        Before any internal processes will be canceled, all registered XCloseListener must be notified. Any of them can disagree with a CloseVetoException too. It's forbidden to catch this exception inside the called close() method because the caller must get this information!
        
        If somewhere disagree with a CloseVetoException it will not clear who has to close the object again after still running processes was finished. The parameter DeliverOwnership regulate that. If it is set to FALSE the caller of the method close() will be the owner of this object in every case. Then it's not allowed to call close() from any other place (may a registered XCloseListener). If it is set to TRUE the caller gives up his ownership. If a XCloseListener throw the veto exception he will be the new owner of the closing object. This information is passed to the listener by a parameter of his notification method XCloseListener.queryClosing(). After his operations was finished he MUST try to close it again. If the closing object itself disagree by an exception and the parameter DeliverOwnership was set to TRUE the object will be his own owner with all consequences of that. Note:There is no way to get the ownership back if it was delivered!
        
        If this method was already called on an object it should return without any reaction. Normally it's possible to throw a com.sun.star.lang.DisposedException for already disposed or closed objects (which represent a com.sun.star.uno.RuntimeException and can be thrown by every interface call), but it shouldn't be used here. The veto exception should be the only way to indicates the result.

        Raises:
            CloseVetoException: ``CloseVetoException``
        """
        ...

__all__ = ['XCloseable']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_condition_entry import XConditionEntry as XConditionEntry_e2340d32
if typing.TYPE_CHECKING:
    from .x_data_bar_entry import XDataBarEntry as XDataBarEntry_c61d0c1a
    from ..util.color import Color as Color_68e908c5

class DataBar(XConditionEntry_e2340d32):
    """
    Service Class


    See Also:
        `API DataBar <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataBar.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataBar'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DataBarEntries(self) -> typing.Tuple[XDataBarEntry_c61d0c1a, ...]:
        """
        """
        ...

    @abstractproperty
    def AxisColor(self) -> Color_68e908c5:
        """
        """
        ...

    @abstractproperty
    def AxisPosition(self) -> int:
        """
        See com.sun.star.sheet.DataBarAxis for possible values.
        """
        ...

    @abstractproperty
    def Color(self) -> Color_68e908c5:
        """
        """
        ...

    @abstractproperty
    def MaximumLength(self) -> float:
        """
        Maximum databar length in percent of cell width.
        
        Allowed values are (0, 1000) but larger than MinimumLength.
        """
        ...

    @abstractproperty
    def MinimumLength(self) -> float:
        """
        Minimum databar length in percent of cell width.
        
        Allowed values are [0, 100) but smaller than MaximumLength.
        """
        ...

    @abstractproperty
    def NegativeColor(self) -> Color_68e908c5:
        """
        """
        ...

    @abstractproperty
    def ShowValue(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def UseGradient(self) -> bool:
        """
        """
        ...

    @abstractproperty
    def UseNegativeColor(self) -> bool:
        """
        """
        ...


__all__ = ['DataBar']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.sax
from __future__ import annotations
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XDTDHandler(XInterface_8f010a43):
    """
    receives events according to the DTD of the document.
    
    The SAX parser may report these events in any order, regardless of the order in which the notations and unparsed entities were declared; however, all DTD events must be reported after the document handler's startDocument event, and before the first startElement event. It is up to the application to store the information for future use (perhaps in a hash table or object tree). If the application encounters attributes of type \"NOTATION\", \"ENTITY\", or \"ENTITIES\", it can use the information that it obtained through this interface to find the entity and/or notation that corresponds with the attribute value.

    See Also:
        `API XDTDHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XDTDHandler.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.sax'
    __ooo_full_ns__: str = 'com.sun.star.xml.sax.XDTDHandler'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.sax.XDTDHandler'

    @abstractmethod
    def notationDecl(self, sName: str, sPublicId: str, sSystemId: str) -> None:
        """
        receives notification of a notation declaration event.
        """
        ...
    @abstractmethod
    def unparsedEntityDecl(self, sName: str, sPublicId: str, sSystemId: str, sNotationName: str) -> None:
        """
        receives notification of an unparsed entity declaration event.
        """
        ...

__all__ = ['XDTDHandler']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.drawing.framework.anchor_binding_mode import AnchorBindingMode as AnchorBindingMode
from ....lo.drawing.framework.basic_pane_factory import BasicPaneFactory as BasicPaneFactory
from ....lo.drawing.framework.basic_tool_bar_factory import BasicToolBarFactory as BasicToolBarFactory
from ....lo.drawing.framework.basic_view_factory import BasicViewFactory as BasicViewFactory
from ....lo.drawing.framework.border_type import BorderType as BorderType
from ....lo.drawing.framework.configuration import Configuration as Configuration
from ....lo.drawing.framework.configuration_change_event import ConfigurationChangeEvent as ConfigurationChangeEvent
from ....lo.drawing.framework.configuration_controller import ConfigurationController as ConfigurationController
from ....lo.drawing.framework.module_controller import ModuleController as ModuleController
from ....lo.drawing.framework.resource_activation_mode import ResourceActivationMode as ResourceActivationMode
from ....lo.drawing.framework.resource_id import ResourceId as ResourceId
from ....lo.drawing.framework.tab_bar_button import TabBarButton as TabBarButton
from ....lo.drawing.framework.x_configuration import XConfiguration as XConfiguration
from ....lo.drawing.framework.x_configuration_change_listener import XConfigurationChangeListener as XConfigurationChangeListener
from ....lo.drawing.framework.x_configuration_change_request import XConfigurationChangeRequest as XConfigurationChangeRequest
from ....lo.drawing.framework.x_configuration_controller import XConfigurationController as XConfigurationController
from ....lo.drawing.framework.x_configuration_controller_broadcaster import XConfigurationControllerBroadcaster as XConfigurationControllerBroadcaster
from ....lo.drawing.framework.x_configuration_controller_request_queue import XConfigurationControllerRequestQueue as XConfigurationControllerRequestQueue
from ....lo.drawing.framework.x_controller_manager import XControllerManager as XControllerManager
from ....lo.drawing.framework.x_module_controller import XModuleController as XModuleController
from ....lo.drawing.framework.x_pane import XPane as XPane
from ....lo.drawing.framework.x_pane2 import XPane2 as XPane2
from ....lo.drawing.framework.x_pane_border_painter import XPaneBorderPainter as XPaneBorderPainter
from ....lo.drawing.framework.x_relocatable_resource import XRelocatableResource as XRelocatableResource
from ....lo.drawing.framework.x_resource import XResource as XResource
from ....lo.drawing.framework.x_resource_factory import XResourceFactory as XResourceFactory
from ....lo.drawing.framework.x_resource_factory_manager import XResourceFactoryManager as XResourceFactoryManager
from ....lo.drawing.framework.x_resource_id import XResourceId as XResourceId
from ....lo.drawing.framework.x_tab_bar import XTabBar as XTabBar
from ....lo.drawing.framework.x_tool_bar import XToolBar as XToolBar
from ....lo.drawing.framework.x_view import XView as XView



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .x_encryption_protected_source import XEncryptionProtectedSource as XEncryptionProtectedSource_8cdf11a3
from ..io.x_seekable import XSeekable as XSeekable_79540954
from ..io.x_stream import XStream as XStream_678908a4
from ..lang.x_component import XComponent as XComponent_98dc0ab5

class StorageStream(XPropertySet_bc180bfa, XEncryptionProtectedSource_8cdf11a3, XSeekable_79540954, XStream_678908a4, XComponent_98dc0ab5):
    """
    Service Class

    This is a service that represents a stream that can be provided by XStorage.openStreamElement() call implemented by Storage service.
    
    In case a stream is open with read-write access only one instance of the stream can exist.

    See Also:
        `API StorageStream <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1StorageStream.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.StorageStream'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsCompressed(self) -> bool:
        """
        specifies if the stream should be compressed next time it is stored.
        """
        ...

    @abstractproperty
    def IsEncrypted(self) -> bool:
        """
        allows to detect if the stream is encrypted.
        
        The property value TRUE means that the stream is currently encrypted. FALSE - the stream is not encrypted.
        
        If somebody sets a password explicitly by using XEncryptionProtectedSource interface the value is automatically set to TRUE. If the interface is used to remove the encryption - the value is automatically set to FALSE.
        """
        ...

    @abstractproperty
    def MediaType(self) -> str:
        """
        allows to get and set media type of the stream.
        """
        ...

    @abstractproperty
    def Size(self) -> int:
        """
        allows to detect size of the stream in bytes.
        """
        ...

    @abstractproperty
    def UseCommonStoragePasswordEncryption(self) -> bool:
        """
        specifies whether the stream will become encrypted next time the common storage password holder is committed.
        
        The property value TRUE means that the stream will become encrypted after the closest storage in the parent hierarchy, that has common storage password, is committed. FALSE - the stream will not react to commit of such a storage.
        
        In case stream is not encrypted and the property is set to TRUE, the stream will stay non-encrypted until the closest storage in the parent hierarchy, that has common storage password, is committed. On the commit the stream will be encrypted with the common storage password. If there is no such storage in the hierarchy the stream will not be encrypted at all. Thus this property must be set very carefully.
        
        If somebody sets a password explicitly by using XEncryptionProtectedSource interface the value is automatically set to FALSE and the stream becomes encrypted with specified password immediately.
        
        In case stream is encrypted one and the value is set to TRUE the stream becomes non-encrypted until the common storage password holder is committed. The data about previously set password ( if any ) will be removed and the stream can be accessed as non-encrypted stream.
        """
        ...


__all__ = ['StorageStream']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.mail
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .mail_exception import MailException as MailException_ba9e0bdd
from ..uno.x_interface import XInterface as XInterface_8f010a43

class SendMailMessageFailedException(MailException_ba9e0bdd):
    """
    Exception Class

    A SendFailedException will be thrown if a mail message could not be sent because the e-mail addresses of some recipients are invalid.
    
    E-mail addresses have to conform to RFC 822.
    
    **since**
    
        OOo 2.0

    See Also:
        `API SendMailMessageFailedException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1mail_1_1SendMailMessageFailedException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.mail'
    __ooo_full_ns__: str = 'com.sun.star.mail.SendMailMessageFailedException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.mail.SendMailMessageFailedException'
    __pyunostruct__: str = 'com.sun.star.mail.SendMailMessageFailedException'

    typeName: str = 'com.sun.star.mail.SendMailMessageFailedException'
    """Literal Constant ``com.sun.star.mail.SendMailMessageFailedException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None, InvalidAddresses: typing.Optional[typing.Tuple[str, ...]] = (), ValidSentAddresses: typing.Optional[typing.Tuple[str, ...]] = (), ValidUnsentAddresses: typing.Optional[typing.Tuple[str, ...]] = ()) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            InvalidAddresses (typing.Tuple[str, ...], optional): InvalidAddresses value.
            ValidSentAddresses (typing.Tuple[str, ...], optional): ValidSentAddresses value.
            ValidUnsentAddresses (typing.Tuple[str, ...], optional): ValidUnsentAddresses value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
            "InvalidAddresses": InvalidAddresses,
            "ValidSentAddresses": ValidSentAddresses,
            "ValidUnsentAddresses": ValidUnsentAddresses,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._invalid_addresses = kwargs["InvalidAddresses"]
        self._valid_sent_addresses = kwargs["ValidSentAddresses"]
        self._valid_unsent_addresses = kwargs["ValidUnsentAddresses"]
        inst_keys = ('InvalidAddresses', 'ValidSentAddresses', 'ValidUnsentAddresses')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)

    @property
    def InvalidAddresses(self) -> typing.Tuple[str, ...]:
        """
        The addresses which are invalid because they do not conform to RFC 822.
        """
        return self._invalid_addresses
    
    @InvalidAddresses.setter
    def InvalidAddresses(self, value: typing.Tuple[str, ...]) -> None:
        self._invalid_addresses = value

    @property
    def ValidSentAddresses(self) -> typing.Tuple[str, ...]:
        """
        The addresses to which the mail message was sent successfully.
        """
        return self._valid_sent_addresses
    
    @ValidSentAddresses.setter
    def ValidSentAddresses(self, value: typing.Tuple[str, ...]) -> None:
        self._valid_sent_addresses = value

    @property
    def ValidUnsentAddresses(self) -> typing.Tuple[str, ...]:
        """
        The addresses which are valid but to which the message was not sent.
        """
        return self._valid_unsent_addresses
    
    @ValidUnsentAddresses.setter
    def ValidUnsentAddresses(self, value: typing.Tuple[str, ...]) -> None:
        self._valid_unsent_addresses = value


__all__ = ['SendMailMessageFailedException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.dnd
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .drag_source_drag_event import DragSourceDragEvent as DragSourceDragEvent_d53c12da
    from .drag_source_drop_event import DragSourceDropEvent as DragSourceDropEvent_d5d412f1
    from .drag_source_event import DragSourceEvent as DragSourceEvent_8ccf115c

class XDragSourceListener(XEventListener_c7230c4a):
    """
    This interface must be implemented by any drag gesture recognizer implementation that a drag source supports.

    See Also:
        `API XDragSourceListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDragSourceListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.XDragSourceListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.dnd.XDragSourceListener'

    @abstractmethod
    def dragDropEnd(self, dsde: DragSourceDropEvent_d5d412f1) -> None:
        """
        This method is invoked to signify that the Drag and Drop operation is complete.
        """
        ...
    @abstractmethod
    def dragEnter(self, dsde: DragSourceDragEvent_d53c12da) -> None:
        """
        Called as the hotspot enters a platform dependent drop site.
        
        NOTE: currently this notification can not be ensured by all implementations. Do not rely on it !
        """
        ...
    @abstractmethod
    def dragExit(self, dse: DragSourceEvent_8ccf115c) -> None:
        """
        Called as the hotspot exits a platform dependent drop site.
        
        NOTE: Currently this notification can not be ensured by all implementations. Do not rely on it !
        """
        ...
    @abstractmethod
    def dragOver(self, dsde: DragSourceDragEvent_d53c12da) -> None:
        """
        Called as the hotspot moves over a platform dependent drop site.
        """
        ...
    @abstractmethod
    def dropActionChanged(self, dsde: DragSourceDragEvent_d53c12da) -> None:
        """
        Called when the user has modified the drop gesture.
        """
        ...

__all__ = ['XDragSourceListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
import typing
from abc import abstractproperty
from .chart3_d_bar_properties import Chart3DBarProperties as Chart3DBarProperties_22f00ec5
from ..drawing.fill_properties import FillProperties as FillProperties_f1200da8
from ..drawing.line_properties import LineProperties as LineProperties_f13f0da9
from ..style.character_properties import CharacterProperties as CharacterProperties_1d4f0ef3
from ..xml.user_defined_attributes_supplier import UserDefinedAttributesSupplier as UserDefinedAttributesSupplier_9fbe1222
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc

class ChartDataPointProperties(Chart3DBarProperties_22f00ec5, FillProperties_f1200da8, LineProperties_f13f0da9, CharacterProperties_1d4f0ef3, UserDefinedAttributesSupplier_9fbe1222):
    """
    Service Class

    specifies all the properties for the graphic object of a data point (e.g., a single bar in a bar chart).
    
    Text properties correlate to the data description of the data point. There is a similar service for a group of graphic elements called ChartDataRowProperties for the properties of whole data rows.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API ChartDataPointProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1ChartDataPointProperties.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartDataPointProperties'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def DataCaption(self) -> int:
        """
        specifies how the captions of data points are displayed.
        """
        ...

    @abstractproperty
    def LabelPlacement(self) -> int:
        """
        specifies a relative position for the data label
        """
        ...

    @abstractproperty
    def LabelSeparator(self) -> str:
        """
        specifies a string that is used to separate the parts of a data label (caption)
        """
        ...

    @abstractproperty
    def NumberFormat(self) -> int:
        """
        specifies a number format for the display of the value in the data label
        """
        ...

    @abstractproperty
    def PercentageNumberFormat(self) -> int:
        """
        specifies a number format for the display of the percentage value in the data label
        """
        ...

    @abstractproperty
    def SegmentOffset(self) -> int:
        """
        the offset by which pie segments in a PieDiagram are dragged outside from the center.
        
        This value is given in percent of the radius.
        """
        ...

    @abstractproperty
    def SymbolBitmap(self) -> XGraphic_a4da0afc:
        """
        In charts that support symbols, you can set this property to a graphic object.
        
        This graphic is then used as symbol for each data point.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def SymbolBitmapURL(self) -> str:
        """
        In charts that support symbols, you can set this property to any valid URL that points to a graphic file.
        
        This graphic is then used as symbol for each data point.
        
        When you query this value you get an internal URL of the embedded graphic.
        """
        ...

    @abstractproperty
    def SymbolType(self) -> int:
        """
        specifies the type of symbols if the current chart type supports the usage of symbols.
        """
        ...

    @abstractproperty
    def TextWordWrap(self) -> bool:
        """
        specifies if the text of a data label (caption) must be wrapped
        
        **since**
        
            LibreOffice 5.1
        """
        ...


__all__ = ['ChartDataPointProperties']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.embed
from __future__ import annotations
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d

class FileSystemStorageFactory(XSingleServiceFactory_27210f0d):
    """
    Service Class

    The FileSystemStorageFactory is a service that allows to create a FileSystemStorage based on URL.
    
    The URL must point to a folder.
    
    In case com.sun.star.lang.XSingleServiceFactory.createInstance() call is used the result storage will be open in read-write mode based on an arbitrary file system folder.
    
    In case com.sun.star.lang.XSingleServiceFactory.createInstanceWithArguments() call is used a sequence of the following parameters can be used:
    
    The parameters are optional, that means that sequence can be empty or contain only first parameter, or first and second one. In case no parameters are provided the call works the same way as com.sun.star.lang.XSingleServiceFactory.createInstance(). In case only first parameter is provided, the storage is opened in readonly mode.
    
    The opened storages can support read access in addition to specified one.

    See Also:
        `API FileSystemStorageFactory <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1embed_1_1FileSystemStorageFactory.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.embed'
    __ooo_full_ns__: str = 'com.sun.star.embed.FileSystemStorageFactory'
    __ooo_type_name__: str = 'service'


__all__ = ['FileSystemStorageFactory']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text.fieldmaster
from __future__ import annotations
import typing
from abc import abstractproperty
from ..text_field_master import TextFieldMaster as TextFieldMaster_d6410cc2
if typing.TYPE_CHECKING:
    from ...beans.property_values import PropertyValues as PropertyValues_d6470ce6
    from ...lang.locale import Locale as Locale_70d308fa

class Bibliography(TextFieldMaster_d6410cc2):
    """
    Service Class

    specifies service of a Bibliography field master.

    See Also:
        `API Bibliography <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1fieldmaster_1_1Bibliography.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text.fieldmaster'
    __ooo_full_ns__: str = 'com.sun.star.text.fieldmaster.Bibliography'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SortKeys(self) -> typing.Tuple[PropertyValues_d6470ce6, ...]:
        """
        determines the sorting of the bibliography entries in a bibliography index.
        
        This property is used if the property IsSortByPosition is not set. Each contained element of the sequence is a sequence of the following two properties:
        """
        ...

    @abstractproperty
    def BracketAfter(self) -> str:
        """
        determines the closing bracket used to display the bibliography text fields.
        """
        ...

    @abstractproperty
    def BracketBefore(self) -> str:
        """
        determines the opening bracket used to display the bibliography text fields.
        """
        ...

    @abstractproperty
    def IsNumberEntries(self) -> bool:
        """
        determines whether the bibliography text fields are numbered.
        
        If FALSE the short name of the bibliography entry is displayed instead.
        """
        ...

    @abstractproperty
    def IsSortByPosition(self) -> bool:
        """
        determines whether the bibliography entries in a bibliography index are sorted by the document position.
        
        If FALSE the SortKey property determines the sorting of the entries.
        """
        ...

    @abstractproperty
    def Locale(self) -> Locale_70d308fa:
        """
        contains the locale of the field master
        """
        ...

    @abstractproperty
    def SortAlgorithm(self) -> str:
        """
        contains the name of the sort algorithm that is used to sort the text fields.
        """
        ...


__all__ = ['Bibliography']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class ChartDataValue(object):
    """
    Struct Class

    describes a single data value, including the error
    
    This struct is currently used nowhere.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API ChartDataValue <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1chart_1_1ChartDataValue.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.ChartDataValue'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.chart.ChartDataValue'
    """Literal Constant ``com.sun.star.chart.ChartDataValue``"""

    def __init__(self, Value: typing.Optional[float] = 0.0, HighError: typing.Optional[float] = 0.0, LowError: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            Value (float, optional): Value value.
            HighError (float, optional): HighError value.
            LowError (float, optional): LowError value.
        """
        super().__init__()

        if isinstance(Value, ChartDataValue):
            oth: ChartDataValue = Value
            self.Value = oth.Value
            self.HighError = oth.HighError
            self.LowError = oth.LowError
            return

        kargs = {
            "Value": Value,
            "HighError": HighError,
            "LowError": LowError,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._value = kwargs["Value"]
        self._high_error = kwargs["HighError"]
        self._low_error = kwargs["LowError"]


    @property
    def Value(self) -> float:
        """
        value by itself.
        """
        return self._value

    @Value.setter
    def Value(self, value: float) -> None:
        self._value = value

    @property
    def HighError(self) -> float:
        """
        highest possible error value.
        """
        return self._high_error

    @HighError.setter
    def HighError(self, value: float) -> None:
        self._high_error = value

    @property
    def LowError(self) -> float:
        """
        lowest possible error value.
        """
        return self._low_error

    @LowError.setter
    def LowError(self, value: float) -> None:
        self._low_error = value


__all__ = ['ChartDataValue']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.system.windows
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .jump_list_item import JumpListItem as JumpListItem_3f370fad

class XJumpList(XInterface_8f010a43):
    """
    Specifies an interface for adding custom jump lists to the task bar (Windows only)
    
    To add a new jump list, call
    
    Use XJumpList.abortList to cancel a current list building session. Use XJumpList.getRemovedItems to see which items were removed by the user.
    
    **since**
    
        LibreOffice 7.4

    See Also:
        `API XJumpList <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1system_1_1windows_1_1XJumpList.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.system.windows'
    __ooo_full_ns__: str = 'com.sun.star.system.windows.XJumpList'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.system.windows.XJumpList'

    @abstractmethod
    def abortList(self) -> None:
        """
        Aborts a list building session started with beginList.

        Raises:
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...
    @abstractmethod
    def addTasks(self, jumpListItems: typing.Tuple[JumpListItem_3f370fad, ...]) -> None:
        """
        Add items to the \"Tasks\" category.
        
        This category is system-defined and the category title cannot be changed. Also the user cannot remove or pin items from this category (as he can with items added via XJumpList.appendCategory ).

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...
    @abstractmethod
    def appendCategory(self, category: str, jumpListItems: typing.Tuple[JumpListItem_3f370fad, ...]) -> None:
        """
        Add a jump list category.
        
        Users can pin or remove items added via this method. Use XJumpList.getRemovedItems to see which items were removed by the user.
        
        Make sure you don't add items which the user has removed before (check the result of getRemovedItems before updating a category). If you try to add items which the user removed before, they will be silently ignored and not added to the list.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...
    @abstractmethod
    def beginList(self, application: str) -> None:
        """
        Start a new jump list.
        
        \"Startcenter\" will map to the generic \"LibreOffice\" icon.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...
    @abstractmethod
    def commitList(self) -> None:
        """
        Commits the list.

        Raises:
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...
    @abstractmethod
    def deleteList(self, application: str) -> None:
        """
        Deletes the Jump List for a certain application.
        
        \"Startcenter\" will map to the generic \"LibreOffice\" icon.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getRemovedItems(self, application: str) -> typing.Tuple[JumpListItem_3f370fad, ...]:
        """
        Returns items that were removed from the jump list by the user.
        
        appendCategory will ignore items which were removed by the user before. Use this method to learn which items were removed by the user.
        
        \"Startcenter\" will map to the generic \"LibreOffice\" icon.
        """
        ...
    @abstractmethod
    def showFrequentFiles(self) -> None:
        """
        Display the frequently used files (populated by LibreOffice)

        Raises:
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...
    @abstractmethod
    def showRecentFiles(self) -> None:
        """
        Display the recently used files (populated by LibreOffice)

        Raises:
            com.sun.star.util.InvalidStateException: ``InvalidStateException``
        """
        ...

__all__ = ['XJumpList']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class ViewSettings(XPropertySet_bc180bfa):
    """
    Service Class

    provides access to the settings of the controller of a text document.
    
    **since**
    
        LibreOffice 5.1

    See Also:
        `API ViewSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1ViewSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.ViewSettings'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def HideWhitespace(self) -> bool:
        """
        If this property is TRUE, whitespaces around pages are hidden.
        
        **since**
        
            LibreOffice 5.1
        """
        ...

    @abstractproperty
    def HorizontalRulerMetric(self) -> int:
        """
        metric unit of the horizontal ruler
        
        Uses values com.sun.star.awt.FieldUnit
        
        **since**
        
            OOo 3.1
        """
        ...

    @abstractproperty
    def IsExecuteHyperlinks(self) -> bool:
        """
        If this property is TRUE hyperlinks in the document are executed (loaded) on mouse click.
        
        Otherwise they are handled like normal text.
        """
        ...

    @abstractproperty
    def IsRasterVisible(self) -> bool:
        """
        Specifies whether to display the grid or not.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def IsSnapToRaster(self) -> bool:
        """
        Specifies whether to move frames, drawing elements, and form functions only between grid points.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def IsVertRulerRightAligned(self) -> bool:
        """
        If this property is TRUE, the vertical ruler is aligned to the right side of the view and the vertical scrollbar is on the left.
        """
        ...

    @abstractproperty
    def RasterResolutionX(self) -> int:
        """
        Defines the unit of measure for the spacing between grid points on the X-axis.
        
        The value must be greater than 0. The application may enforce more restricting bounds for the value.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def RasterResolutionY(self) -> int:
        """
        Defines the unit of measure for the spacing between grid points on the Y-axis.
        
        The value must be greater than 0. The application may enforce more restricting bounds for the value.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def RasterSubdivisionX(self) -> int:
        """
        Specifies the number of intervals between grid points on the X-axis.
        
        The value must be greater or equal to 0, and the application may enforce an upper bound for the value.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def RasterSubdivisionY(self) -> int:
        """
        Specifies the number of intervals between grid points on the Y-axis.
        
        The value must be greater or equal to 0, and the application may enforce an upper bound for the value.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def ShowAnnotations(self) -> bool:
        """
        If this property is TRUE, annotations (notes) are visible.
        """
        ...

    @abstractproperty
    def ShowBookmarks(self) -> bool:
        """
        If this property is TRUE, bookmark positions are displayed.
        
        **since**
        
            LibreOffice 7.0
        """
        ...

    @abstractproperty
    def ShowBreaks(self) -> bool:
        """
        If this property is TRUE, paragraph line breaks are visible.
        """
        ...

    @abstractproperty
    def ShowChangesInMargin(self) -> bool:
        """
        If this property is TRUE, tracked deletions are shown in margin.
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def ShowContentTips(self) -> bool:
        """
        If this property is TRUE, tips for document content are shown, typically in a help balloon when the mouse is over the content.
        
        **since**
        
            LibreOffice 4.1
        """
        ...

    @abstractproperty
    def ShowDrawings(self) -> bool:
        """
        If this property is TRUE, shapes are visible.
        """
        ...

    @abstractproperty
    def ShowFieldCommands(self) -> bool:
        """
        If this property is TRUE, text fields are shown with their commands; otherwise the content is visible.
        """
        ...

    @abstractproperty
    def ShowFootnoteBackground(self) -> bool:
        """
        If this property is TRUE, footnotes symbols are displayed with gray background.
        """
        ...

    @abstractproperty
    def ShowGraphics(self) -> bool:
        """
        If this property is TRUE, graphic objects are visible.
        """
        ...

    @abstractproperty
    def ShowHiddenCharacters(self) -> bool:
        """
        If this property is TRUE, hidden characters are displayed.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def ShowHiddenParagraphs(self) -> bool:
        """
        If this property is TRUE, hidden paragraphs are displayed.
        """
        ...

    @abstractproperty
    def ShowHiddenText(self) -> bool:
        """
        If this property is TRUE, hidden text is displayed.
        """
        ...

    @abstractproperty
    def ShowHoriRuler(self) -> bool:
        """
        If this property is TRUE and the property ShowRulers is TRUE, the horizontal ruler is displayed.
        """
        ...

    @abstractproperty
    def ShowHoriScrollBar(self) -> bool:
        """
        If this property is TRUE and the property ShowRulers is TRUE, the horizontal scroll bar is displayed.
        """
        ...

    @abstractproperty
    def ShowIndexMarkBackground(self) -> bool:
        """
        If this property is TRUE, index marks are displayed with gray background.
        """
        ...

    @abstractproperty
    def ShowInlineTooltips(self) -> bool:
        """
        If this property is TRUE, tooltips for tracked changes are shown.
        
        **since**
        
            LibreOffice 6.1
        """
        ...

    @abstractproperty
    def ShowNonprintingCharacters(self) -> bool:
        """
        If this property is TRUE, the settings of non-printing characters are applied.
        
        This option controls the use of the settings ShowHiddenCharacters, ShowTabstops, ShowSpaces, ShowBreaks and ShowParaBreaks
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def ShowOnlineLayout(self) -> bool:
        """
        If this property is TRUE the document will be displayed as if it were a HTML document.
        """
        ...

    @abstractproperty
    def ShowOutlineContentVisibilityButton(self) -> bool:
        """
        If this property is TRUE, the outline content visibility toggle button is shown.
        
        **since**
        
            LibreOffice 7.1
        """
        ...

    @abstractproperty
    def ShowParaBreaks(self) -> bool:
        """
        If this property is TRUE, paragraph breaks are visible.
        """
        ...

    @abstractproperty
    def ShowProtectedSpaces(self) -> bool:
        """
        If this property is TRUE, protected spaces (hard spaces) are displayed with gray background.
        """
        ...

    @abstractproperty
    def ShowRulers(self) -> bool:
        """
        ShowHoriRuler and ShowVertRuler determine whether a ruler is visible.
        """
        ...

    @abstractproperty
    def ShowScrollBarTips(self) -> bool:
        """
        If this property is TRUE, and the scroll bar is shown, a tool tip is displayed while scrolling.
        
        **since**
        
            LibreOffice 4.2
        """
        ...

    @abstractproperty
    def ShowSoftHyphens(self) -> bool:
        """
        If this property is TRUE, soft hyphens are displayed with gray background.
        """
        ...

    @abstractproperty
    def ShowSpaces(self) -> bool:
        """
        If this property is TRUE, spaces are displayed with dots.
        """
        ...

    @abstractproperty
    def ShowTableBoundaries(self) -> bool:
        """
        If this property is TRUE, table boundaries are displayed.
        """
        ...

    @abstractproperty
    def ShowTables(self) -> bool:
        """
        If this property is TRUE, tables are visible.
        """
        ...

    @abstractproperty
    def ShowTabstops(self) -> bool:
        """
        If this property is TRUE, tab stops are visible.
        """
        ...

    @abstractproperty
    def ShowTextBoundaries(self) -> bool:
        """
        If this property is TRUE, text boundaries are displayed.
        """
        ...

    @abstractproperty
    def ShowTextFieldBackground(self) -> bool:
        """
        If this property is TRUE, text fields are displayed with gray background.
        """
        ...

    @abstractproperty
    def ShowVertRuler(self) -> bool:
        """
        If this property is TRUE, the vertical ruler is displayed.
        """
        ...

    @abstractproperty
    def ShowVertScrollBar(self) -> bool:
        """
        If this property is TRUE, the vertical scroll bar is displayed.
        """
        ...

    @abstractproperty
    def SmoothScrolling(self) -> bool:
        """
        If this property is TRUE, smooth scrolling is active.
        """
        ...

    @abstractproperty
    def TreatSubOutlineLevelsAsContent(self) -> bool:
        """
        If this property is TRUE, sub outline levels are treated as content in outline content visibility actions.
        
        **since**
        
            LibreOffice 7.2
        """
        ...

    @abstractproperty
    def UseHeaderFooterMenu(self) -> bool:
        """
        If this property is TRUE, the advanced menu for header/footer is shown.
        
        **since**
        
            LibreOffice 6.2
        """
        ...

    @abstractproperty
    def VerticalRulerMetric(self) -> int:
        """
        metric unit of the vertical ruler
        
        Uses values from com.sun.star.awt.FieldUnit
        
        **since**
        
            OOo 3.1
        """
        ...

    @abstractproperty
    def ZoomType(self) -> int:
        """
        This property defines the zoom type for the document.
        """
        ...

    @abstractproperty
    def ZoomValue(self) -> int:
        """
        Defines the zoom value to use.
        
        Valid only if the ZoomType is set to com.sun.star.view.DocumentZoomType.BY_VALUE.
        """
        ...


__all__ = ['ViewSettings']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.runtime
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .filter_event import FilterEvent as FilterEvent_d780e56

class XFilterControllerListener(XEventListener_c7230c4a):
    """
    is implemented by components listening for events fired by an XFilterController.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XFilterControllerListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFilterControllerListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.runtime'
    __ooo_full_ns__: str = 'com.sun.star.form.runtime.XFilterControllerListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.runtime.XFilterControllerListener'

    @abstractmethod
    def disjunctiveTermAdded(self, Event: FilterEvent_d780e56) -> None:
        """
        is fired when a disjunctive term was added to the filter of the filter controller.
        
        FilterEvent.DisjunctiveTerm is the index of the disjunctive term which was added.
        
        FilterEvent.FilterComponent and FilterEvent.PredicateExpression are not used for this event type.
        """
        ...
    @abstractmethod
    def disjunctiveTermRemoved(self, Event: FilterEvent_d780e56) -> None:
        """
        is fired when a disjunctive term was removed from the filter of the filter controller.
        
        FilterEvent.DisjunctiveTerm is the index of the disjunctive term which was removed.
        
        FilterEvent.FilterComponent and FilterEvent.PredicateExpression are not used for this event type.
        """
        ...
    @abstractmethod
    def predicateExpressionChanged(self, Event: FilterEvent_d780e56) -> None:
        """
        is fired when a single predicate expression of the filter represented by the filter controller changed.
        
        FilterEvent.DisjunctiveTerm is the index of the disjunctive term in which the expression changed. This usually equals XFilterController.ActiveTerm.
        
        FilterEvent.FilterComponent denotes the index of the filter component whose predicate expression changed.
        
        FilterEvent.PredicateExpression is the new predicate expressions.
        """
        ...

__all__ = ['XFilterControllerListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.io
# Libre Office Version: 7.4
import typing
from .io_exception import IOException as IOException_8c450a27
from ..uno.x_interface import XInterface as XInterface_8f010a43

class NotConnectedException(IOException_8c450a27):
    """
    Exception Class

    is thrown when a read/write operation is tried on an instance that has not been chained properly.

    See Also:
        `API NotConnectedException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1io_1_1NotConnectedException.html>`_
    """

    __ooo_ns__: str = 'com.sun.star.io'
    __ooo_full_ns__: str = 'com.sun.star.io.NotConnectedException'
    __ooo_type_name__: str = 'exception'
    __pyunointerface__: str = 'com.sun.star.io.NotConnectedException'
    __pyunostruct__: str = 'com.sun.star.io.NotConnectedException'

    typeName: str = 'com.sun.star.io.NotConnectedException'
    """Literal Constant ``com.sun.star.io.NotConnectedException``"""

    def __init__(self, Message: typing.Optional[str] = '', Context: typing.Optional[XInterface_8f010a43] = None) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
        """
        kargs = {
            "Message": Message,
            "Context": Context,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        super()._init(**kwargs)


__all__ = ['NotConnectedException']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .changes_set import ChangesSet as ChangesSet_99de0aab

class XChangesBatch(XInterface_8f010a43):
    """
    this interface enables applying a set of changes in one batch transaction.
    
    An object implementing this interface allows other interfaces to change its state locally. It will keep a list of pending changes until such changes are committed or canceled.
    
    Only when they are explicitly committed will these changes take effect persistently or globally.

    See Also:
        `API XChangesBatch <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1util_1_1XChangesBatch.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.XChangesBatch'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.util.XChangesBatch'

    @abstractmethod
    def commitChanges(self) -> None:
        """
        commits any pending changes.
        
        The exact action depends on the concrete service.

        Raises:
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
        ...
    @abstractmethod
    def getPendingChanges(self) -> ChangesSet_99de0aab:
        """
        queries for any pending changes that can be committed.
        """
        ...
    @abstractmethod
    def hasPendingChanges(self) -> bool:
        """
        checks whether this object has any pending changes that can be committed.
        """
        ...

__all__ = ['XChangesBatch']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class RuleTerm(object):
    """
    Struct Class

    describes a term.
    
    A term is used to select objects to which a rule should apply.

    See Also:
        `API RuleTerm <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1ucb_1_1RuleTerm.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.RuleTerm'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.ucb.RuleTerm'
    """Literal Constant ``com.sun.star.ucb.RuleTerm``"""

    def __init__(self, Property: typing.Optional[str] = '', Operand: typing.Optional[object] = None, Operator: typing.Optional[int] = 0, CaseSensitive: typing.Optional[bool] = False, RegularExpression: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Property (str, optional): Property value.
            Operand (object, optional): Operand value.
            Operator (int, optional): Operator value.
            CaseSensitive (bool, optional): CaseSensitive value.
            RegularExpression (bool, optional): RegularExpression value.
        """
        super().__init__()

        if isinstance(Property, RuleTerm):
            oth: RuleTerm = Property
            self.Property = oth.Property
            self.Operand = oth.Operand
            self.Operator = oth.Operator
            self.CaseSensitive = oth.CaseSensitive
            self.RegularExpression = oth.RegularExpression
            return

        kargs = {
            "Property": Property,
            "Operand": Operand,
            "Operator": Operator,
            "CaseSensitive": CaseSensitive,
            "RegularExpression": RegularExpression,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._property = kwargs["Property"]
        self._operand = kwargs["Operand"]
        self._operator = kwargs["Operator"]
        self._case_sensitive = kwargs["CaseSensitive"]
        self._regular_expression = kwargs["RegularExpression"]


    @property
    def Property(self) -> str:
        """
        the name of the property used to match the term.
        """
        return self._property

    @Property.setter
    def Property(self, value: str) -> None:
        self._property = value

    @property
    def Operand(self) -> object:
        """
        the value of the property used to compare with the document property.
        """
        return self._operand

    @Operand.setter
    def Operand(self, value: object) -> None:
        self._operand = value

    @property
    def Operator(self) -> int:
        """
        the operator used to compare the property of the document with the given value (e.g.
        
        \"contains\" or \"greater equal\").
        
        The value can be one of the RuleOperator constants.
        """
        return self._operator

    @Operator.setter
    def Operator(self, value: int) -> None:
        self._operator = value

    @property
    def CaseSensitive(self) -> bool:
        """
        this flag indicates whether a string \"operand\" shall be compared case sensitive.
        """
        return self._case_sensitive

    @CaseSensitive.setter
    def CaseSensitive(self, value: bool) -> None:
        self._case_sensitive = value

    @property
    def RegularExpression(self) -> bool:
        """
        this flag indicates whether a string \"operand\" shall be treated as a regular expression.
        """
        return self._regular_expression

    @RegularExpression.setter
    def RegularExpression(self, value: bool) -> None:
        self._regular_expression = value


__all__ = ['RuleTerm']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from ...dyn.util.alias_programmatic_pair import AliasProgrammaticPair as AliasProgrammaticPair
with suppress(ImportError):
    from ...dyn.util.atom_class_request import AtomClassRequest as AtomClassRequest
with suppress(ImportError):
    from ...dyn.util.atom_description import AtomDescription as AtomDescription
with suppress(ImportError):
    from ...dyn.util.bootstrap_macro_expander import BootstrapMacroExpander as BootstrapMacroExpander
with suppress(ImportError):
    from ...dyn.util.cell_protection import CellProtection as CellProtection
with suppress(ImportError):
    from ...dyn.util.changes_event import ChangesEvent as ChangesEvent
with suppress(ImportError):
    from ...dyn.util.changes_set import ChangesSet as ChangesSet
with suppress(ImportError):
    from ...dyn.util.close_veto_exception import CloseVetoException as CloseVetoException
with suppress(ImportError):
    from ...dyn.util.color import Color as Color
with suppress(ImportError):
    from ...dyn.util.data_editor_event import DataEditorEvent as DataEditorEvent
with suppress(ImportError):
    from ...dyn.util.data_editor_event_type import DataEditorEventType as DataEditorEventType
with suppress(ImportError):
    from ...dyn.util.date import Date as Date
with suppress(ImportError):
    from ...dyn.util.date_time import DateTime as DateTime
with suppress(ImportError):
    from ...dyn.util.date_time_range import DateTimeRange as DateTimeRange
with suppress(ImportError):
    from ...dyn.util.date_time_with_timezone import DateTimeWithTimezone as DateTimeWithTimezone
with suppress(ImportError):
    from ...dyn.util.date_with_timezone import DateWithTimezone as DateWithTimezone
with suppress(ImportError):
    from ...dyn.util.duration import Duration as Duration
with suppress(ImportError):
    from ...dyn.util.element_change import ElementChange as ElementChange
with suppress(ImportError):
    from ...dyn.util.endianness import Endianness as Endianness
with suppress(ImportError):
    from ...dyn.util.endianness import EndiannessEnum as EndiannessEnum
with suppress(ImportError):
    from ...dyn.util.invalid_state_exception import InvalidStateException as InvalidStateException
with suppress(ImportError):
    from ...dyn.util.job_manager import JobManager as JobManager
with suppress(ImportError):
    from ...dyn.util.language import Language as Language
with suppress(ImportError):
    from ...dyn.util.macro_expander import MacroExpander as MacroExpander
with suppress(ImportError):
    from ...dyn.util.malformed_number_format_exception import MalformedNumberFormatException as MalformedNumberFormatException
with suppress(ImportError):
    from ...dyn.util.measure_unit import MeasureUnit as MeasureUnit
with suppress(ImportError):
    from ...dyn.util.measure_unit import MeasureUnitEnum as MeasureUnitEnum
with suppress(ImportError):
    from ...dyn.util.mode_change_event import ModeChangeEvent as ModeChangeEvent
with suppress(ImportError):
    from ...dyn.util.not_locked_exception import NotLockedException as NotLockedException
with suppress(ImportError):
    from ...dyn.util.not_numeric_exception import NotNumericException as NotNumericException
with suppress(ImportError):
    from ...dyn.util.number_format import NumberFormat as NumberFormat
with suppress(ImportError):
    from ...dyn.util.number_format import NumberFormatEnum as NumberFormatEnum
with suppress(ImportError):
    from ...dyn.util.number_format_properties import NumberFormatProperties as NumberFormatProperties
with suppress(ImportError):
    from ...dyn.util.number_format_settings import NumberFormatSettings as NumberFormatSettings
with suppress(ImportError):
    from ...dyn.util.number_formats import NumberFormats as NumberFormats
with suppress(ImportError):
    from ...dyn.util.number_formats_supplier import NumberFormatsSupplier as NumberFormatsSupplier
with suppress(ImportError):
    from ...dyn.util.number_formatter import NumberFormatter as NumberFormatter
with suppress(ImportError):
    from ...dyn.util.office_installation_directories import OfficeInstallationDirectories as OfficeInstallationDirectories
with suppress(ImportError):
    from ...dyn.util.path_settings import PathSettings as PathSettings
with suppress(ImportError):
    from ...dyn.util.path_substitution import PathSubstitution as PathSubstitution
with suppress(ImportError):
    from ...dyn.util.replace_descriptor import ReplaceDescriptor as ReplaceDescriptor
with suppress(ImportError):
    from ...dyn.util.revision_tag import RevisionTag as RevisionTag
with suppress(ImportError):
    from ...dyn.util.search_algorithms import SearchAlgorithms as SearchAlgorithms
with suppress(ImportError):
    from ...dyn.util.search_algorithms2 import SearchAlgorithms2 as SearchAlgorithms2
with suppress(ImportError):
    from ...dyn.util.search_algorithms2 import SearchAlgorithms2Enum as SearchAlgorithms2Enum
with suppress(ImportError):
    from ...dyn.util.search_descriptor import SearchDescriptor as SearchDescriptor
with suppress(ImportError):
    from ...dyn.util.search_flags import SearchFlags as SearchFlags
with suppress(ImportError):
    from ...dyn.util.search_flags import SearchFlagsEnum as SearchFlagsEnum
with suppress(ImportError):
    from ...dyn.util.search_options import SearchOptions as SearchOptions
with suppress(ImportError):
    from ...dyn.util.search_options2 import SearchOptions2 as SearchOptions2
with suppress(ImportError):
    from ...dyn.util.search_result import SearchResult as SearchResult
with suppress(ImportError):
    from ...dyn.util.sort_descriptor import SortDescriptor as SortDescriptor
with suppress(ImportError):
    from ...dyn.util.sort_descriptor2 import SortDescriptor2 as SortDescriptor2
with suppress(ImportError):
    from ...dyn.util.sort_field import SortField as SortField
with suppress(ImportError):
    from ...dyn.util.sort_field_type import SortFieldType as SortFieldType
with suppress(ImportError):
    from ...dyn.util.sortable import Sortable as Sortable
with suppress(ImportError):
    from ...dyn.util.text_search import TextSearch as TextSearch
with suppress(ImportError):
    from ...dyn.util.text_search2 import TextSearch2 as TextSearch2
with suppress(ImportError):
    from ...dyn.util.time import Time as Time
with suppress(ImportError):
    from ...dyn.util.time_with_timezone import TimeWithTimezone as TimeWithTimezone
with suppress(ImportError):
    from ...dyn.util.tri_state import TriState as TriState
with suppress(ImportError):
    from ...dyn.util.url import URL as URL
with suppress(ImportError):
    from ...dyn.util.url_transformer import URLTransformer as URLTransformer
with suppress(ImportError):
    from ...dyn.util.uri_abbreviation import UriAbbreviation as UriAbbreviation
with suppress(ImportError):
    from ...dyn.util.veto_exception import VetoException as VetoException
with suppress(ImportError):
    from ...dyn.util.x_accounting import XAccounting as XAccounting
with suppress(ImportError):
    from ...dyn.util.x_atom_server import XAtomServer as XAtomServer
with suppress(ImportError):
    from ...dyn.util.x_binary_data_container import XBinaryDataContainer as XBinaryDataContainer
with suppress(ImportError):
    from ...dyn.util.x_broadcaster import XBroadcaster as XBroadcaster
with suppress(ImportError):
    from ...dyn.util.x_cache_info import XCacheInfo as XCacheInfo
with suppress(ImportError):
    from ...dyn.util.x_cancellable import XCancellable as XCancellable
with suppress(ImportError):
    from ...dyn.util.x_chainable import XChainable as XChainable
with suppress(ImportError):
    from ...dyn.util.x_changes_batch import XChangesBatch as XChangesBatch
with suppress(ImportError):
    from ...dyn.util.x_changes_listener import XChangesListener as XChangesListener
with suppress(ImportError):
    from ...dyn.util.x_changes_notifier import XChangesNotifier as XChangesNotifier
with suppress(ImportError):
    from ...dyn.util.x_changes_set import XChangesSet as XChangesSet
with suppress(ImportError):
    from ...dyn.util.x_cloneable import XCloneable as XCloneable
with suppress(ImportError):
    from ...dyn.util.x_close_broadcaster import XCloseBroadcaster as XCloseBroadcaster
with suppress(ImportError):
    from ...dyn.util.x_close_listener import XCloseListener as XCloseListener
with suppress(ImportError):
    from ...dyn.util.x_closeable import XCloseable as XCloseable
with suppress(ImportError):
    from ...dyn.util.x_data_editor import XDataEditor as XDataEditor
with suppress(ImportError):
    from ...dyn.util.x_data_editor_listener import XDataEditorListener as XDataEditorListener
with suppress(ImportError):
    from ...dyn.util.x_flush_listener import XFlushListener as XFlushListener
with suppress(ImportError):
    from ...dyn.util.x_flushable import XFlushable as XFlushable
with suppress(ImportError):
    from ...dyn.util.x_importable import XImportable as XImportable
with suppress(ImportError):
    from ...dyn.util.x_indent import XIndent as XIndent
with suppress(ImportError):
    from ...dyn.util.x_job_manager import XJobManager as XJobManager
with suppress(ImportError):
    from ...dyn.util.x_link_update import XLinkUpdate as XLinkUpdate
with suppress(ImportError):
    from ...dyn.util.x_localized_aliases import XLocalizedAliases as XLocalizedAliases
with suppress(ImportError):
    from ...dyn.util.x_lockable import XLockable as XLockable
with suppress(ImportError):
    from ...dyn.util.x_macro_expander import XMacroExpander as XMacroExpander
with suppress(ImportError):
    from ...dyn.util.x_mergeable import XMergeable as XMergeable
with suppress(ImportError):
    from ...dyn.util.x_mode_change_approve_listener import XModeChangeApproveListener as XModeChangeApproveListener
with suppress(ImportError):
    from ...dyn.util.x_mode_change_broadcaster import XModeChangeBroadcaster as XModeChangeBroadcaster
with suppress(ImportError):
    from ...dyn.util.x_mode_change_listener import XModeChangeListener as XModeChangeListener
with suppress(ImportError):
    from ...dyn.util.x_mode_selector import XModeSelector as XModeSelector
with suppress(ImportError):
    from ...dyn.util.x_modifiable import XModifiable as XModifiable
with suppress(ImportError):
    from ...dyn.util.x_modifiable2 import XModifiable2 as XModifiable2
with suppress(ImportError):
    from ...dyn.util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster
with suppress(ImportError):
    from ...dyn.util.x_modify_listener import XModifyListener as XModifyListener
with suppress(ImportError):
    from ...dyn.util.x_number_format_previewer import XNumberFormatPreviewer as XNumberFormatPreviewer
with suppress(ImportError):
    from ...dyn.util.x_number_format_types import XNumberFormatTypes as XNumberFormatTypes
with suppress(ImportError):
    from ...dyn.util.x_number_formats import XNumberFormats as XNumberFormats
with suppress(ImportError):
    from ...dyn.util.x_number_formats_supplier import XNumberFormatsSupplier as XNumberFormatsSupplier
with suppress(ImportError):
    from ...dyn.util.x_number_formatter import XNumberFormatter as XNumberFormatter
with suppress(ImportError):
    from ...dyn.util.x_number_formatter2 import XNumberFormatter2 as XNumberFormatter2
with suppress(ImportError):
    from ...dyn.util.x_office_installation_directories import XOfficeInstallationDirectories as XOfficeInstallationDirectories
with suppress(ImportError):
    from ...dyn.util.x_path_settings import XPathSettings as XPathSettings
with suppress(ImportError):
    from ...dyn.util.x_property_replace import XPropertyReplace as XPropertyReplace
with suppress(ImportError):
    from ...dyn.util.x_protectable import XProtectable as XProtectable
with suppress(ImportError):
    from ...dyn.util.x_refresh_listener import XRefreshListener as XRefreshListener
with suppress(ImportError):
    from ...dyn.util.x_refreshable import XRefreshable as XRefreshable
with suppress(ImportError):
    from ...dyn.util.x_replace_descriptor import XReplaceDescriptor as XReplaceDescriptor
with suppress(ImportError):
    from ...dyn.util.x_replaceable import XReplaceable as XReplaceable
with suppress(ImportError):
    from ...dyn.util.x_search_descriptor import XSearchDescriptor as XSearchDescriptor
with suppress(ImportError):
    from ...dyn.util.x_searchable import XSearchable as XSearchable
with suppress(ImportError):
    from ...dyn.util.x_sortable import XSortable as XSortable
with suppress(ImportError):
    from ...dyn.util.x_string_abbreviation import XStringAbbreviation as XStringAbbreviation
with suppress(ImportError):
    from ...dyn.util.x_string_escape import XStringEscape as XStringEscape
with suppress(ImportError):
    from ...dyn.util.x_string_mapping import XStringMapping as XStringMapping
with suppress(ImportError):
    from ...dyn.util.x_string_substitution import XStringSubstitution as XStringSubstitution
with suppress(ImportError):
    from ...dyn.util.x_string_width import XStringWidth as XStringWidth
with suppress(ImportError):
    from ...dyn.util.x_text_search import XTextSearch as XTextSearch
with suppress(ImportError):
    from ...dyn.util.x_text_search2 import XTextSearch2 as XTextSearch2
with suppress(ImportError):
    from ...dyn.util.x_time_stamped import XTimeStamped as XTimeStamped
with suppress(ImportError):
    from ...dyn.util.xurl_transformer import XURLTransformer as XURLTransformer
with suppress(ImportError):
    from ...dyn.util.x_unique_id_factory import XUniqueIDFactory as XUniqueIDFactory
with suppress(ImportError):
    from ...dyn.util.x_updatable import XUpdatable as XUpdatable
with suppress(ImportError):
    from ...dyn.util.x_updatable2 import XUpdatable2 as XUpdatable2
with suppress(ImportError):
    from ...dyn.util.x_veto import XVeto as XVeto
with suppress(ImportError):
    from ...dyn.util.the_macro_expander import theMacroExpander as theMacroExpander
with suppress(ImportError):
    from ...dyn.util.the_office_installation_directories import theOfficeInstallationDirectories as theOfficeInstallationDirectories
with suppress(ImportError):
    from ...dyn.util.the_path_settings import thePathSettings as thePathSettings



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.container
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_enumerable_map import XEnumerableMap as XEnumerableMap_dc50e41

class EnumerableMap(XEnumerableMap_dc50e41):
    """
    Service Class

    provides a default XEnumerableMap implementation
    
    For the keys put into the map using XMap.put() or createImmutable(), the following rules apply:
    
    For the values put into the map using XMap.put() or createImmutable(), the following rules apply:
    
    The factory methods of the XEnumerableMap interface support both isolated and non-isolated enumerators. The latter one will be automatically disposed when the map changes after enumerator creation, so every attempt to use them will result in a com.sun.star.lang.DisposedException being thrown.

    See Also:
        `API EnumerableMap <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1container_1_1EnumerableMap.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.container'
    __ooo_full_ns__: str = 'com.sun.star.container.EnumerableMap'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, KeyType: object, ValueType: object) -> None:
        """
        creates an instance mapping from the given key type to the given value type

        Raises:
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
        """
        ...
    @abstractmethod
    def createImmutable(self, KeyType: object, ValueType: object, Values: typing.Tuple[typing.Tuple[object, object], ...]) -> None:
        """
        creates an instance mapping from the given key type to the given value type
        
        The resulting map is immutable, so later alter operations on it will fail with a com.sun.star.lang.NoSupportException.

        Raises:
            com.sun.star.beans.IllegalTypeException: ``IllegalTypeException``
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...

__all__ = ['EnumerableMap']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_slide_sorter_base import XSlideSorterBase as XSlideSorterBase_c400e37
if typing.TYPE_CHECKING:
    from ..awt.x_window import XWindow as XWindow_713b0924
    from ..frame.x_controller import XController as XController_b00e0b8f

class SlideSorter(XSlideSorterBase_c400e37):
    """
    Service Class

    A slide sorter shows previews for a set of slides, typically all slides in a document, and allows the selection, reordering, creation, and deletion of slides.
    
    In the drawing framework a slide sorter is regarded as a view.

    See Also:
        `API SlideSorter <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1SlideSorter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.SlideSorter'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, xViewId: object, xController: XController_b00e0b8f, xParentWindow: XWindow_713b0924) -> None:
        """
        Create a new slide sorter object.
        """
        ...

__all__ = ['SlideSorter']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class FillDateMode(Enum):
    """
    Enum Class


    See Also:
        `API FillDateMode <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#a2ea1aac24b8de3ac28ac5a6ec79a80ca>`_
    """
    __ooo_ns__: str = "com.sun.star.sheet"
    __ooo_full_ns__: str = "com.sun.star.sheet.FillDateMode"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.sheet.FillDateMode"

    FILL_DATE_DAY = "FILL_DATE_DAY"
    """
    for every new value a single day is added.
    """
    FILL_DATE_MONTH = "FILL_DATE_MONTH"
    """
    for every new value one month is added (day keeps unchanged).
    """
    FILL_DATE_WEEKDAY = "FILL_DATE_WEEKDAY"
    """
    for every new value a single day is added, but Saturdays and Sundays are skipped.
    """
    FILL_DATE_YEAR = "FILL_DATE_YEAR"
    """
    for every new value one year is added (day and month keep unchanged).
    """

__all__ = ["FillDateMode"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#


from contextlib import suppress
import warnings
warnings.filterwarnings('module')
warnings.warn('The cssdyn namespace is deprecated. Use dyn instead.', DeprecationWarning, stacklevel=2)

with suppress(ImportError):
    from .....dyn.xml.crypto.sax.const_of_security_id import ConstOfSecurityId as ConstOfSecurityId
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.const_of_security_id import ConstOfSecurityIdEnum as ConstOfSecurityIdEnum
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.element_mark_priority import ElementMarkPriority as ElementMarkPriority
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.element_mark_type import ElementMarkType as ElementMarkType
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.element_stack_item import ElementStackItem as ElementStackItem
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_blocker_monitor import XBlockerMonitor as XBlockerMonitor
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_decryption_result_broadcaster import XDecryptionResultBroadcaster as XDecryptionResultBroadcaster
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_decryption_result_listener import XDecryptionResultListener as XDecryptionResultListener
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_element_stack_keeper import XElementStackKeeper as XElementStackKeeper
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_encryption_result_broadcaster import XEncryptionResultBroadcaster as XEncryptionResultBroadcaster
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_encryption_result_listener import XEncryptionResultListener as XEncryptionResultListener
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_key_collector import XKeyCollector as XKeyCollector
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_mission_taker import XMissionTaker as XMissionTaker
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_reference_collector import XReferenceCollector as XReferenceCollector
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_reference_resolved_broadcaster import XReferenceResolvedBroadcaster as XReferenceResolvedBroadcaster
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_reference_resolved_listener import XReferenceResolvedListener as XReferenceResolvedListener
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.xsax_event_keeper import XSAXEventKeeper as XSAXEventKeeper
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.xsax_event_keeper_status_change_broadcaster import XSAXEventKeeperStatusChangeBroadcaster as XSAXEventKeeperStatusChangeBroadcaster
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.xsax_event_keeper_status_change_listener import XSAXEventKeeperStatusChangeListener as XSAXEventKeeperStatusChangeListener
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_security_sax_event_keeper import XSecuritySAXEventKeeper as XSecuritySAXEventKeeper
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_signature_creation_result_broadcaster import XSignatureCreationResultBroadcaster as XSignatureCreationResultBroadcaster
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_signature_creation_result_listener import XSignatureCreationResultListener as XSignatureCreationResultListener
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_signature_verify_result_broadcaster import XSignatureVerifyResultBroadcaster as XSignatureVerifyResultBroadcaster
with suppress(ImportError):
    from .....dyn.xml.crypto.sax.x_signature_verify_result_listener import XSignatureVerifyResultListener as XSignatureVerifyResultListener



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
if typing.TYPE_CHECKING:
    from ..awt.x_device import XDevice as XDevice_70ba08fc
    from ..i18n.x_forbidden_characters import XForbiddenCharacters as XForbiddenCharacters_df60e2d
    from ..lang.locale import Locale as Locale_70d308fa
    from ..util.date import Date as Date_60040844

class SpreadsheetDocumentSettings(XPropertySet_bc180bfa):
    """
    Service Class

    contributes properties to control the configuration which is global for all views of a spreadsheet document.
    
    **since**
    
        OOo 3.0
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API SpreadsheetDocumentSettings <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1SpreadsheetDocumentSettings.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.SpreadsheetDocumentSettings'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CalcAsShown(self) -> bool:
        """
        specifies whether calculations are performed with the rounded values displayed in cells (set to TRUE) instead of the internal values (set to FALSE).
        """
        ...

    @abstractproperty
    def CharLocale(self) -> Locale_70d308fa:
        """
        contains the standard document language for Western text.
        """
        ...

    @abstractproperty
    def CharLocaleAsian(self) -> Locale_70d308fa:
        """
        contains the standard document language for Asian text.
        """
        ...

    @abstractproperty
    def CharLocaleComplex(self) -> Locale_70d308fa:
        """
        contains the standard document language for Complex text.
        """
        ...

    @abstractproperty
    def DefaultTabStop(self) -> int:
        """
        specifies the width of default tabulators.
        """
        ...

    @abstractproperty
    def ForbiddenCharacters(self) -> XForbiddenCharacters_df60e2d:
        """
        contains the interface XForbiddenCharacters.
        """
        ...

    @abstractproperty
    def HasDrawPages(self) -> bool:
        """
        If this property is set the document has DrawPages.
        
        Use this property to find out, whether the document has DrawPages or not, because the getDrawPage method on the XDrawPageSupplier and the getDrawPages method on the XDrawPagesSupplier always creates the DrawPages if there are none; and this is very slow and needs more memory.
        """
        ...

    @abstractproperty
    def IgnoreCase(self) -> bool:
        """
        specifies whether upper and lower cases are treated as equal when comparing cells.
        """
        ...

    @abstractproperty
    def IsAdjustHeightEnabled(self) -> bool:
        """
        specifies whether the automatic adjustment of the row height is enabled.
        
        This boolean is actually a counter internally, of the number of times something has locked the height, so setting it to false will only perform one unlock operation, and might leave it still locked
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def IsExecuteLinkEnabled(self) -> bool:
        """
        specifies whether the automatic execution of links is enabled.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def IsIterationEnabled(self) -> bool:
        """
        enables iterated calculation of circular references.
        """
        ...

    @abstractproperty
    def IsLoaded(self) -> bool:
        """
        specifies whether the document data are already loaded.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def IsRecordChangesProtected(self) -> bool:
        """
        specifies whether changes record is protected.
        
        **since**
        
            LibreOffice 5.0
        """
        ...

    @abstractproperty
    def IsUndoEnabled(self) -> bool:
        """
        specifies whether the undo command is enabled.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def IterationCount(self) -> int:
        """
        specifies how many iterations are carried out.
        
        This setting is only used, if iteration is enabled using SpreadsheetDocumentSettings.IsIterationEnabled.
        """
        ...

    @abstractproperty
    def IterationEpsilon(self) -> float:
        """
        specifies the point at which a change in results will stop the iteration.
        
        More exactly it specifies a difference in the change of the result between two iterations. If the result difference is less than or equal to this epsilon-value, the iteration is stopped.
        
        This setting is only used, if iteration is enabled using SpreadsheetDocumentSettings.IsIterationEnabled.
        """
        ...

    @abstractproperty
    def LookUpLabels(self) -> bool:
        """
        specifies whether column or row labels are looked up from anywhere on the sheet.
        
        Explicitly defined label ranges are used even if this property is set to FALSE.
        """
        ...

    @abstractproperty
    def MatchWholeCell(self) -> bool:
        """
        specifies whether filter criteria must match entire cell contents.
        """
        ...

    @abstractproperty
    def NullDate(self) -> Date_60040844:
        """
        specifies the date that is represented by the value zero.
        """
        ...

    @abstractproperty
    def RecordChanges(self) -> bool:
        """
        specifies whether changes record is enabled.
        
        No modification applied if the record changes protection is activated information given by SpreadsheetDocumentSettings.IsRecordChangesProtected
        
        **since**
        
            LibreOffice 5.0
        """
        ...

    @abstractproperty
    def ReferenceDevice(self) -> XDevice_70ba08fc:
        """
        contains the reference device used for formatting the document.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def RegularExpressions(self) -> bool:
        """
        specifies whether regular expressions in formulas are enabled, e.g., for functions which look up spreadsheet contents.
        
        RegularExpressions and Wildcards are mutually exclusive, only one can have the value TRUE. If both are set to TRUE via API calls then the last one set takes precedence.
        """
        ...

    @abstractproperty
    def SpellOnline(self) -> bool:
        """
        enables online spell checking.
        """
        ...

    @abstractproperty
    def StandardDecimals(self) -> int:
        """
        specifies the number of decimals in the default number format.
        """
        ...

    @abstractproperty
    def Wildcards(self) -> bool:
        """
        specifies whether wildcards in formulas are enabled, e.g., for functions which look up spreadsheet contents.
        
        Wildcards and RegularExpressions are mutually exclusive, only one can have the value TRUE. If both are set to TRUE via API calls then the last one set takes precedence.
        
        **since**
        
            LibreOffice 5.2
        """
        ...


__all__ = ['SpreadsheetDocumentSettings']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
import typing
import uno
from abc import abstractmethod
from .x_text_markup import XTextMarkup as XTextMarkup_a5d60b3a
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..lang.locale import Locale as Locale_70d308fa

class XFlatParagraph(XTextMarkup_a5d60b3a):
    """
    provides functionality to ...
    
    **since**
    
        OOo 3.0

    See Also:
        `API XFlatParagraph <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1text_1_1XFlatParagraph.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.XFlatParagraph'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.text.XFlatParagraph'

    @abstractmethod
    def changeAttributes(self, nPos: int, nLen: int, aAttributes: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        replace the attributes of the specific text with the given set of attributes.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def changeText(self, nPos: int, nLen: int, NewText: str, aAttributes: typing.Tuple[PropertyValue_c9610c73, ...]) -> None:
        """
        replace the specific text with new text.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getLanguageOfText(self, nPos: int, nLen: int) -> Locale_70d308fa:
        """
        get the language of the specific text

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getLanguagePortions(self) -> uno.ByteSequence:
        """
        get a list of indexes that separate each two different languages
        """
        ...
    @abstractmethod
    def getPrimaryLanguageOfText(self, nPos: int, nLen: int) -> Locale_70d308fa:
        """
        get the single most probable language of the specific text, especially after getLanguageOfText fails

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getText(self) -> str:
        """
        get the content of the paragraph
        """
        ...
    @abstractmethod
    def isChecked(self, nType: int) -> bool:
        """
        returns whether the respective text node has already been processed
        """
        ...
    @abstractmethod
    def isModified(self) -> bool:
        """
        check whether the content has been modified
        """
        ...
    @abstractmethod
    def setChecked(self, nType: int, bVal: bool) -> None:
        """
        change the \"checked\" flag of the respective text node, i.e., mark the text node as \"processed\"
        """
        ...

__all__ = ['XFlatParagraph']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.dnd
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .drop_target_drag_enter_event import DropTargetDragEnterEvent as DropTargetDragEnterEvent_3a2d14e5
    from .drop_target_drag_event import DropTargetDragEvent as DropTargetDragEvent_d60612e7
    from .drop_target_drop_event import DropTargetDropEvent as DropTargetDropEvent_d69e12fe
    from .drop_target_event import DropTargetEvent as DropTargetEvent_8d651169

class XDropTargetListener(XEventListener_c7230c4a):
    """
    This interface is the callback interface used by the drop target object to provide notification of Drag and Drop operations that involve the subject drop target.
    
    Methods of this interface may be implemented to provide \"drag under\" visual feedback to the user throughout the Drag and Drop operation.

    See Also:
        `API XDropTargetListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTargetListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.dnd'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.dnd.XDropTargetListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.dnd.XDropTargetListener'

    @abstractmethod
    def dragEnter(self, dtdee: DropTargetDragEnterEvent_3a2d14e5) -> None:
        """
        Called when a drag operation has encountered the drop target.
        """
        ...
    @abstractmethod
    def dragExit(self, dte: DropTargetEvent_8d651169) -> None:
        """
        The drag operation has departed the drop target without dropping.
        """
        ...
    @abstractmethod
    def dragOver(self, dtde: DropTargetDragEvent_d60612e7) -> None:
        """
        Called when a drag operation is ongoing on the drop target.
        """
        ...
    @abstractmethod
    def drop(self, dtde: DropTargetDropEvent_d69e12fe) -> None:
        """
        The drag operation has terminated with a drop on this drop target.
        
        NOTE: The implementation has to wait until the method XDropTargetDropContext.dropComplete() is called before releasing the data for the drop operation. This should occur before returning from drop in a normal flow of operation. Also, the implementor of XDropTargetListener should not assume the DropTargetDropEvent to be meaningful after returning from the XDropTargetListener.drop() method.
        """
        ...
    @abstractmethod
    def dropActionChanged(self, dtde: DropTargetDragEvent_d60612e7) -> None:
        """
        Called when the user has modified the drop gesture.
        """
        ...

__all__ = ['XDropTargetListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.beans
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class TolerantPropertySetResultType(metaclass=UnoConstMeta, type_name="com.sun.star.beans.TolerantPropertySetResultType", name_space="com.sun.star.beans"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.beans.TolerantPropertySetResultType``"""
        pass

    class TolerantPropertySetResultTypeEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.beans.TolerantPropertySetResultType", name_space="com.sun.star.beans"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.beans.TolerantPropertySetResultType`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.beans import TolerantPropertySetResultType as TolerantPropertySetResultType
    else:
        # keep document generators happy
        from ...lo.beans.tolerant_property_set_result_type import TolerantPropertySetResultType as TolerantPropertySetResultType

    class TolerantPropertySetResultTypeEnum(IntEnum):
        """
        Enum of Const Class TolerantPropertySetResultType

        specifies the possible failure types when using the com.sun.star.beans.XTolerantMultiPropertySet interface.
        
        It usually matches one of the exception types that may occur when using the com.sun.star.beans.XPropertySet or com.sun.star.beans.XMultiPropertySet interfaces.
        """
        SUCCESS = TolerantPropertySetResultType.SUCCESS
        """
        the property has been successfully set or retrieved.
        """
        UNKNOWN_PROPERTY = TolerantPropertySetResultType.UNKNOWN_PROPERTY
        """
        the property is not available.
        
        For example if a com.sun.star.beans.UnknownPropertyException was caught.
        """
        ILLEGAL_ARGUMENT = TolerantPropertySetResultType.ILLEGAL_ARGUMENT
        """
        the value used with the property is not valid.
        
        For example if a com.sun.star.lang.IllegalArgumentException was caught.
        """
        PROPERTY_VETO = TolerantPropertySetResultType.PROPERTY_VETO
        """
        the property could not be changed at that time.
        
        For example if a com.sun.star.beans.PropertyVetoException was caught.
        """
        WRAPPED_TARGET = TolerantPropertySetResultType.WRAPPED_TARGET
        """
        a com.sun.star.lang.WrappedTargetException did occur.
        """
        UNKNOWN_FAILURE = TolerantPropertySetResultType.UNKNOWN_FAILURE
        """
        the operation failed and the reason is not known.
        """

__all__ = ['TolerantPropertySetResultType', 'TolerantPropertySetResultTypeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.util
from __future__ import annotations
from abc import abstractproperty
from .x_search_descriptor import XSearchDescriptor as XSearchDescriptor_ef600d93

class SearchDescriptor(XSearchDescriptor_ef600d93):
    """
    Service Class

    describes what and how to search within a container.
    
    **since**
    
        LibreOffice 5.2

    See Also:
        `API SearchDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1util_1_1SearchDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.util'
    __ooo_full_ns__: str = 'com.sun.star.util.SearchDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def SearchBackwards(self) -> bool:
        """
        If TRUE, the search is done backwards in the document.
        """
        ...

    @abstractproperty
    def SearchCaseSensitive(self) -> bool:
        """
        If TRUE, the case of the letters is important for the match.
        """
        ...

    @abstractproperty
    def SearchRegularExpression(self) -> bool:
        """
        If TRUE, the search string is evaluated as a regular expression.
        
        SearchRegularExpression, SearchWildcard and SearchSimilarity are mutually exclusive, only one can be TRUE at the same time.
        """
        ...

    @abstractproperty
    def SearchSimilarity(self) -> bool:
        """
        If TRUE, a \"similarity search\" is performed.
        
        In the case of a similarity search, the following properties specify the kind of similarity:
        
        SearchRegularExpression, SearchWildcard and SearchSimilarity are mutually exclusive, only one can be TRUE at the same time.
        """
        ...

    @abstractproperty
    def SearchSimilarityAdd(self) -> int:
        """
        specifies the number of characters that must be added to match the search pattern.
        """
        ...

    @abstractproperty
    def SearchSimilarityExchange(self) -> int:
        """
        This property specifies the number of characters that must be replaced to match the search pattern.
        """
        ...

    @abstractproperty
    def SearchSimilarityRelax(self) -> bool:
        """
        If TRUE, all similarity rules are applied together.
        
        In the case of a relaxed similarity search, the following properties are applied together:
        """
        ...

    @abstractproperty
    def SearchSimilarityRemove(self) -> int:
        """
        This property specifies the number of characters that may be ignored to match the search pattern.
        """
        ...

    @abstractproperty
    def SearchStyles(self) -> bool:
        """
        If TRUE, it is searched for positions where the paragraph style with the name of the search pattern is applied.
        """
        ...

    @abstractproperty
    def SearchWildcard(self) -> bool:
        """
        If TRUE, the search string is evaluated as a wildcard pattern.
        
        Wildcards are '*' (asterisk) for any sequence of characters, including an empty sequence, and '?' (question mark) for exactly one character. Escape character is '\\' (U+005C REVERSE SOLIDUS) aka backslash, it escapes the special meaning of a question mark, asterisk or escape character that follows immediately after the escape character.
        
        SearchRegularExpression, SearchWildcard and SearchSimilarity are mutually exclusive, only one can be TRUE at the same time.
        
        **since**
        
            LibreOffice 5.2
        """
        ...

    @abstractproperty
    def SearchWords(self) -> bool:
        """
        If TRUE, only complete words will be found.
        """
        ...


__all__ = ['SearchDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ...lo.mail.mail_attachment import MailAttachment as MailAttachment
from ...lo.mail.mail_exception import MailException as MailException
from ...lo.mail.mail_message import MailMessage as MailMessage
from ...lo.mail.mail_service_provider import MailServiceProvider as MailServiceProvider
from ...lo.mail.mail_service_type import MailServiceType as MailServiceType
from ...lo.mail.no_mail_service_provider_exception import NoMailServiceProviderException as NoMailServiceProviderException
from ...lo.mail.no_mail_transport_provider_exception import NoMailTransportProviderException as NoMailTransportProviderException
from ...lo.mail.send_mail_message_failed_exception import SendMailMessageFailedException as SendMailMessageFailedException
from ...lo.mail.x_authenticator import XAuthenticator as XAuthenticator
from ...lo.mail.x_connection_listener import XConnectionListener as XConnectionListener
from ...lo.mail.x_mail_message import XMailMessage as XMailMessage
from ...lo.mail.x_mail_service import XMailService as XMailService
from ...lo.mail.x_mail_service_provider import XMailServiceProvider as XMailServiceProvider
from ...lo.mail.x_smtp_service import XSmtpService as XSmtpService



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.frame
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from .x_frame import XFrame as XFrame_7a570956

class XSynchronousFrameLoader(XInterface_8f010a43):
    """
    loads a resource into a Frame.
    
    Unlike the XFrameLoader interface, this loading will be synchronous.

    See Also:
        `API XSynchronousFrameLoader <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1frame_1_1XSynchronousFrameLoader.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.frame'
    __ooo_full_ns__: str = 'com.sun.star.frame.XSynchronousFrameLoader'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.frame.XSynchronousFrameLoader'

    @abstractmethod
    def cancel(self) -> None:
        """
        cancels the loading process.
        
        No notifications (neither to the frame or the caller) must be notified. Because it's a synchronous process this cancel call can be forced by another thread the loader thread only. Method XSynchronousFrameLoader.load() must return FALSE then and caller of this method XSynchronousFrameLoader.cancel() already knows the state ...
        """
        ...
    @abstractmethod
    def load(self, Descriptor: typing.Tuple[PropertyValue_c9610c73, ...], Frame: XFrame_7a570956) -> bool:
        """
        starts the loading of the specified resource into the specified Frame.
        """
        ...

__all__ = ['XSynchronousFrameLoader']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt.grid
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .grid_data_event import GridDataEvent as GridDataEvent_ebcb0d2a

class XGridDataListener(XEventListener_c7230c4a):
    """
    An instance of this interface is used by the XGridDataModel to get notifications about data model changes.
    
    Usually you must not implement this interface yourself, but you must notify it correctly if you implement the XGridDataModel yourself
    
    .
    
    **since**
    
        OOo 3.3

    See Also:
        `API XGridDataListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1grid_1_1XGridDataListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt.grid'
    __ooo_full_ns__: str = 'com.sun.star.awt.grid.XGridDataListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.grid.XGridDataListener'

    @abstractmethod
    def dataChanged(self, Event: GridDataEvent_ebcb0d2a) -> None:
        """
        is called when existing data in a grid control's data model has been modified.
        """
        ...
    @abstractmethod
    def rowHeadingChanged(self, Event: GridDataEvent_ebcb0d2a) -> None:
        """
        is called when the title of one or more rows changed.
        """
        ...
    @abstractmethod
    def rowsInserted(self, Event: GridDataEvent_ebcb0d2a) -> None:
        """
        is called when one or more rows of data have been inserted into a grid control's data model.
        """
        ...
    @abstractmethod
    def rowsRemoved(self, Event: GridDataEvent_ebcb0d2a) -> None:
        """
        is called when one or more rows of data have been removed from a grid control's data model.
        """
        ...

__all__ = ['XGridDataListener']


